#
# spec file for package grml-zsh-config
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           grml-zsh-config
Version:        0.19.15
Release:        1.1
Summary:        Zsh config ujed by grml
License:        GPL-2.0-only
URL:            https://grml.org/zsh/
Source:         https://github.com/grml/grml-etc-core/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  rubygem(asciidoctor)
Requires:       grep
Requires:       procps
Requires:       sed
Requires:       zsh >= 5.1
BuildArch:      noarch

%description
Zsh configuration files used by grml.

%prep
ls
%setup -q -n grml-etc-core-%{version}

%build
cd doc
%make_build

%install
install -D -m644 etc/skel/.zshrc "%{buildroot}%{_sysconfdir}/skel/.zshrc"
install -D -m644 etc/zsh/keephack "%{buildroot}%{_sysconfdir}/zsh/keephack"
install -D -m644 etc/zsh/zshrc "%{buildroot}%{_sysconfdir}/zsh/zshrc"
install -D -m644 doc/grmlzshrc.5 "%{buildroot}%{_mandir}/man5/grmlzshrc.5"

%files
%doc README.md
%doc %{_sysconfdir}/zsh
%config %{_sysconfdir}/skel/.zshrc
%config %{_sysconfdir}/zsh/keephack
%config %{_sysconfdir}/zsh/zshrc
%{_mandir}/man5/grmlzshrc.5%{?ext_man}

%changelog
* Wed Mar  5 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.19.5:
  * doc/Makefile: drop unused target for copying to grml.org
  * Switch manpage source to asciidoc
  * README: add link to grmlzshrc manpage
  * README: resync install instructions with grml.org/console
  * d/control: Set Rules-Requires-Root: no
  * zshrc: alias afl for apt-file list
  * etc/skel/.zshrc: global alias TZ for timestamp/ts(1)
  * etc/zsh/zshrc: only alias if command is present
  * tmux: status-right: Show IP addresses (similar to our GNU/screen
    configuration)
  * tmux: status-right: Show IP addresses (similar to our GNU/screen
    configuration)
* Tue Jan 28 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.19.4:
  * zshrc: deprecate xunfunction
  * zshrc: remove "hbp" alias
* Wed Jan 22 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.19.13:
  * zsh aliases: add afs(apt-file search)
  * zshenv: drop live-cd only hacks
  * zsh: drop solaris support
* Thu Jan  2 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.19.12:
  * zshrc: use $HOST instead of forking to uname -n
  * zshenv: stop setting HOSTNAME
  * zshrc: remove grml_maintain_name
  * zshrc: stop setting CLICOLOR
  * zshrc: use path_helper on macOS
  * zshrc: remove fink init on macOS
  * zshrc: remove zurl function
  * zshrc: drop aterm workaround
  * zshrc: drop mrxvt workaround
  * zshrc: drop centericq workaround
  * zshrc: remove fink init on macOS
  * zshrc: remove 855resolution function
  * zshrc: remove cdrecord function
  * doc: remove old version info
  * zshrc: require zsh version 5.1
  * zshrc: remove add-zsh-hook from grml_prompt_setup
  * zshrc: remove copy of add-zsh-hook
  * Drop DISTCC_HOSTS variable
* Thu Jan  2 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.19.11:
  * zshrc: set HISTSIZE + SAVEHIST only if not yet set or being set
    to zsh upstream default #160 #169
* Thu Jan  2 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.19.10:
  * Revert "zshrc: increase HISTSIZE + SAVEHIST to our defaults
    also for live system" #169 #160
  * Revert "fix(zshrc): keep existing history restrictions" #169 #160
* Mon Dec 16 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.9:
  * fix(zshrc): keep existing history restrictions
  * zshenv: add ~/.local/bin to default PATH
  * zshrc: increase HISTSIZE + SAVEHIST to our defaults also for live system
* Tue Nov 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.8:
  * Stop shipping /etc/zsh/zlogout to avoid clearing terminal screen
  * debian/preinst: drop deprecated dpkg-divert
  * debian: update Vcs-Git and Vcs-Browser
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.7:
  * etc/skel/.zshrc: set file encoding to UTF8.
  * zshrc: bugfix for _complete_screen_display when using tmux
  * Bump Standards-Version to 4.6.2
* Sat Nov 18 2023 Dirk Müller <dmueller@suse.com>
- update to 0.19.6:
  * etc/skel/.zshrc: suggest J as global alias for jq
    usage.
  * zshrc: weather: fixed outdated url and test -d
* Fri Apr  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Buildrequire python3-txt2tags (default python interpreter version)
  instead of python38-txt2tags.
* Tue Jan 10 2023 Michael Vetter <mvetter@suse.com>
- Initial package of grml-zsh-config 0.19.5 for openSUSE
